==> UW-RestClients-SWS-1.7.3.tar.gz: UW-RestClients-SWS-1.7.3/uw_sws/__init__.py <==
from datetime import datetime
try:
    from urllib.parse import quote
except ImportError:
    from urllib import quote
from uw_pws import PWS
from uw_sws.dao import SWS_DAO
from restclients_core.exceptions import DataFailureException
import json


QUARTER_SEQ = ["winter", "spring", "summer", "autumn"]
DAO = SWS_DAO()
UWPWS = PWS()


def use_v5_resources():
    return True


def parse_sws_date(date_string):
    """
    Takes a date from the SWS response object
    and attempts to parse it using one of the several
    datetime formats used by the SWS
    :param date_string:
    :return: date object
    """
    if date_string is None:
        return None
    date_formats = ["%m/%d/%Y", "%Y-%m-%d", "%Y%m%d"]
    datetime_obj = None
    for fmt in date_formats:
        try:
            datetime_obj = datetime.strptime(date_string, fmt)
        except ValueError:
            continue
        break
    if datetime_obj is None:
        raise ValueError("Unknown SWS date format")
    return datetime_obj


def encode_section_label(label):
    return quote(label, safe="/,")


def get_resource(url):
    """
    Issue a GET request to SWS with the given url
    and return a response in json format.
    :returns: http response with content in json
    """
    response = DAO.getURL(url, {'Accept': 'application/json',
                                'Connection': 'keep-alive'})
    if response.status != 200:
        raise DataFailureException(url, response.status, response.data)
    return json.loads(response.data)

==> UW-RestClients-SWS-2.3.18.tar.gz: UW-RestClients-SWS-2.3.18/uw_sws/__init__.py <==
# Copyright 2021 UW-IT, University of Washington
# SPDX-License-Identifier: Apache-2.0

import json
from urllib.parse import quote
from restclients_core.exceptions import DataFailureException
from uw_pws import PWS
from uw_sws.dao import SWS_DAO, SWS_TIMEZONE, sws_now

QUARTER_SEQ = ["winter", "spring", "summer", "autumn"]
DAO = SWS_DAO()
UWPWS = PWS()


def use_v5_resources():
    return True


def encode_section_label(label):
    return quote(label, safe="/,")


def get_resource(url):
    """
    Issue a GET request to SWS with the given url
    and return a response in json format.
    :returns: http response with content in json
    """
    response = DAO.getURL(url, {'Accept': 'application/json',
                                'Connection': 'keep-alive'})
    if response.status != 200:
        raise DataFailureException(url, response.status, response.data)
    return json.loads(response.data)


def put_resource(url, headers={}, body={}):
    """
    Issue a GET request to SWS with the given url in order to obtain
    an ETag header, followed by a PUT request to the same url. Returns
    a response in json format.
    :returns: http response with content in json
    """
    response = DAO.getURL(url, {'Accept': 'application/json'})

    if response.status != 200:
        raise DataFailureException(url, response.status, response.data)

    headers['If-Match'] = response.headers.get('ETag', '*')
    headers['Content-Type'] = 'application/json; charset=utf-8'

    response = DAO.putURL(url, headers, json.dumps(body))

    if response.status != 200:
        raise DataFailureException(url, response.status, response.data)
    return json.loads(response.data)
